@@ -1,15 +1,17 @@
 """Fleet env module - convenience functions for environment management."""
 
-from .client import make, list_envs, get
+from .client import make, list_envs, get, list_instances
 
 # Import async versions from _async
-from .._async.env.client import make_async, list_envs_async, get_async
+from .._async.env.client import make_async, list_envs_async, get_async, list_instances_async
 
 __all__ = [
     "make",
     "list_envs", 
+    "list_instances",
     "get",
     "make_async",
     "list_envs_async",
+    "list_instances_async",
     "get_async",
 ]
\ No newline at end of file
